import sys
import json

from testwizard.commands_core import CommandBase
from .GetSizeResult import GetSizeResult

class GetElementSizeCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.GetElementSize")
    
    def execute(self, selector):
        if(selector==None):
            raise Exception("selector is required")
        requestObj = [selector]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        return GetSizeResult(response.read(), "GetElementSize was successful", "GetElementSize failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class InputTextCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.InputText")
    
    def execute(self, selector, text):
        
        if(selector==None):
            raise Exception("selector is required")
        if(text==None):
            raise Exception("text is required")
        requestObj = [selector, text]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return SimpleResult(response.read(), "InputText was successful", "InputText failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .GetOrientationResult import GetOrientationResult

class GetOrientationCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.GetOrientation")
    
    def execute(self):
        requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        return GetOrientationResult(response.read(), "GetOrientation was successful", "GetOrientation failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class StartDeviceLoggingCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.StartDeviceLogging")

    def execute(self, filename, username=None, password=None):
        if (filename == None):
            raise Exception("filename is required")

        requestObj = [filename, username, password]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "StartDeviceLogging was successful", "StartDeviceLogging failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class AddCapabilityCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.AddCapability")
    
    def execute(self, name, value):
        
        if(name == None):
            raise Exception("name is required")
        if(value == None):
            raise Exception("value is required")    
        requestObj = json.dumps([name, value])

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return SimpleResult(response.read(), "AddCapability was successful", "AddCapability failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class TouchAction_ReleaseCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.TouchAction_Release")

    def execute(self):
        requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "TouchAction_Release was successful", "TouchAction_Release failed")


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class SwipeArcCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.SwipeArc")

    def execute(self, centerX, centerY, radius, startDegree, degrees, steps):
        if(centerX==None):
            raise Exception("centerX is required")
        if(centerY==None):
            raise Exception("centerY is required")
        if(radius==None):
            raise Exception("radius is required")
        if(startDegree==None):
            raise Exception("startDegree is required")
        if(degrees==None):
            raise Exception("degrees is required")
        if(steps==None):
            raise Exception("steps is required")   

        requestObj = [centerX, centerY, radius, startDegree, degrees, steps]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "SwipeArc was successful", "SwipeArc failed")


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class Android_SendKeyCodeCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.Android_SendKeyCode")
    
    def execute(self, keyCode):
        
        if(keyCode == None):
            raise Exception("keyCode is required")
        
        requestObj = [keyCode]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return SimpleResult(response.read(), "Android_SendKeyCode was successful", "Android_SendKeyCode failed")   


import sys

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

import json
class InitDriverCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.InitDriver")
    
    def execute(self, appPath):
        
        if(appPath):
            requestObj = [appPath]
        else:
            requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return SimpleResult(response.read(), "InitDriver was successful", "InitDriver failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class RunAppInBackgroundCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.RunAppInBackground")

    def execute(self, seconds = None):
        if(seconds!=None):
            requestObj = [seconds]
        else:
            requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "RunAppInBackground was successful", "RunAppInBackground failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementAttributeResult import GetElementAttributeResult

class GetElementAttributeCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.GetElementAttribute")
    
    def execute(self, selector, attribute):
        if(selector==None):
            raise Exception("selector is required")
        if(attribute==None):
            raise Exception("attribute is required")  
        requestObj = [selector, attribute]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        return GetElementAttributeResult(response.read(), "GetElementAttribute was successful", "GetElementAttribute failed")   


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class GetElementLocationResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        ResultBase.__init__(self, True if jsonObj["ok"] else False, successMessage, failMessage + ": " + jsonObj["errorMessage"])

        self.x = jsonObj["x"]
        self.y = jsonObj["y"]


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class SwipeCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.Swipe")
    
    def execute(self, startX, startY, endX, endY, duration):
        if(startX==None):
            raise Exception("startX is required")
        if(startY==None):
            raise Exception("startY is required")
        if(endX==None):
            raise Exception("endX is required")
        if(endY==None):
            raise Exception("endY is required")
        if(duration==None):
            raise Exception("duration is required")

        requestObj = [startX, startY, endX, endY, duration]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "Swipe was successful", "Swipe failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForElementResult import WaitForElementResult

class WaitForElementCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.WaitForElement")

    def execute(self, selector, maxSeconds):
        if(selector==None):
            raise Exception("selector is required")
        if(maxSeconds==None):
            raise Exception("maxSeconds is required")

        requestObj = [selector, maxSeconds]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return WaitForElementResult(response.read(), "WaitForElement was successful", "WaitForElement failed")


import sys
import json

from testwizard.commands_core.ResultBase import ResultBase

class GetSourceResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        ResultBase.__init__(self, True if jsonObj["ok"] else False, successMessage, failMessage + ": " + jsonObj["errorMessage"])

        self.source = jsonObj["source"]



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class ZoomCoordinatesCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.ZoomCoordinates")

    def execute(self, x, y, length):
        if(x==None):
            raise Exception("x is required")
        if(y==None):
            raise Exception("y is required")
        if(length==None):
            raise Exception("length is required")

        requestObj = [x, y, length]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "ZoomCoordinates was successful", "ZoomCoordinates failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .GetSizeResult import GetSizeResult

class GetScreenSizeCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.GetScreenSize")
    
    def execute(self):
        requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        return GetSizeResult(response.read(), "GetScreenSize was successful", "GetScreenSize failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class SetOrientationCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.SetOrientation")

    def execute(self, orientation):
        if(orientation==None):
            raise Exception("orientation is required")

        requestObj = [orientation]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "SetOrientation was successful", "SetOrientation failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class HideKeyboardCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.HideKeyboard")
    
    def execute(self, iOS_Key = None):
        requestObj = []
        if(iOS_Key!=None):
            requestObj = [iOS_Key]
        requestObj = json.dumps(requestObj)
        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return SimpleResult(response.read(), "HideKeyboard was successful", "HideKeyboard failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class TouchAction_WaitCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Mobile.TouchAction_Wait")
    
    def execute(self, duration):
        if(duration == None):
            raise Exception("duration is required")

        requestObj = [duration]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SimpleResult(response.read(), "TouchAction_Wait was successful", "TouchAction_Wait failed")